@@ -1,10 +1,13 @@
 from typing import Any, Dict, List, Text
-from ruth.nlu.featurizers.sparse_featurizers.constants import CLASS_FEATURIZER_UNIQUE_NAME
-from ruth.shared.nlu.ruth_elements import Element
+
+from ruth.nlu.featurizers.featurizer import Featurizer
+from ruth.nlu.featurizers.sparse_featurizers.constants import (
+    CLASS_FEATURIZER_UNIQUE_NAME,
+)
 from ruth.shared.nlu.training_data.collections import TrainData
 
 
-class SparseFeaturizer(Element):
+class SparseFeaturizer(Featurizer):
     def __init__(self, element_config):
         element_config = element_config or {}
         self.element_config = element_config
