@@ -1,7 +1,8 @@
-import json
 from pathlib import Path
 from typing import List, Text
 
+import yaml
+from ruth.cli.constants import EXAMPLES, NLU
 from ruth.constants import INTENT, TEXT
 from ruth.shared.nlu.training_data.ruth_data import RuthData
 
@@ -17,11 +18,15 @@ class TrainData:
     def build(cls, data_path: Path) -> "TrainData":
         training_examples = list()
         with open(data_path, "r") as f:
-            messages = json.load(f)
-        for message in messages:
-            training_examples.append(
-                RuthData.build(intent=message.get(INTENT), text=message.get(TEXT))
-            )
+            yml = yaml.safe_load(f)
+        for intent_ex in yml[NLU]:
+            for value in intent_ex[EXAMPLES][0:-2].split("\n"):
+                training_examples.append(
+                    RuthData.build(
+                        intent=intent_ex["intent"], text=value.replace("- ", "")
+                    )
+                )
+
         return cls(training_examples)
 
     def add_example(self, data: RuthData) -> List[RuthData]:
